@@ -17,7 +17,13 @@ class Project(API):
     def __init__(
         self, project_configuration: ProjectConfiguration, interface: Interface, pyproject_data: dict[str, Any]
     ) -> None:
-        """Initializes the project"""
+        """Initializes the project
+
+        Args:
+            project_configuration: Project-wide configuration
+            interface: Interface for callbacks to write configuration changes
+            pyproject_data: Merged configuration data from all sources
+        """
         self._enabled = False
         self._interface = interface
         self.logger = logging.getLogger('cppython')
@@ -52,9 +58,12 @@ class Project(API):
         """
         return self._enabled
 
-    def install(self) -> None:
+    def install(self, groups: list[str] | None = None) -> None:
         """Installs project dependencies
 
+        Args:
+            groups: Optional list of dependency groups to install in addition to base dependencies
+
         Raises:
             Exception: Provider-specific exceptions are propagated with full context
         """
@@ -66,15 +75,28 @@ class Project(API):
         asyncio.run(self._data.download_provider_tools())
 
         self.logger.info('Installing project')
+
+        # Log active groups
+        if groups:
+            self.logger.info('Installing with dependency groups: %s', ', '.join(groups))
+
         self.logger.info('Installing %s provider', self._data.plugins.provider.name())
 
-        # Let provider handle its own exceptions for better error context
-        self._data.plugins.provider.install()
+        # Validate and log active groups
+        self._data.apply_dependency_groups(groups)
+
+        # Sync before install to allow provider to access generator's resolved configuration
         self._data.sync()
 
-    def update(self) -> None:
+        # Let provider handle its own exceptions for better error context
+        self._data.plugins.provider.install(groups=groups)
+
+    def update(self, groups: list[str] | None = None) -> None:
         """Updates project dependencies
 
+        Args:
+            groups: Optional list of dependency groups to update in addition to base dependencies
+
         Raises:
             Exception: Provider-specific exception
         """
@@ -86,12 +108,22 @@ class Project(API):
         asyncio.run(self._data.download_provider_tools())
 
         self.logger.info('Updating project')
+
+        # Log active groups
+        if groups:
+            self.logger.info('Updating with dependency groups: %s', ', '.join(groups))
+
         self.logger.info('Updating %s provider', self._data.plugins.provider.name())
 
-        # Let provider handle its own exceptions for better error context
-        self._data.plugins.provider.update()
+        # Validate and log active groups
+        self._data.apply_dependency_groups(groups)
+
+        # Sync before update to allow provider to access generator's resolved configuration
         self._data.sync()
 
+        # Let provider handle its own exceptions for better error context
+        self._data.plugins.provider.update(groups=groups)
+
     def publish(self) -> None:
         """Publishes the project
 
